@@ -28,8 +28,6 @@
 #include "phononconfig_p.h"
 #include "platform_p.h"
 
-QT_BEGIN_NAMESPACE
-
 namespace Phonon
 {
 class AudioOutputAdaptor;
@@ -97,7 +95,5 @@ class AudioOutputPrivate : public AbstractAudioOutputPrivate
 };
 } //namespace Phonon
 
-QT_END_NAMESPACE
-
 #endif // AUDIOOUTPUT_P_H
 // vim: sw=4 ts=4 tw=80
